==> kate-debuginfo-17.04.3-2.tar.xz: usr/src/debug/kate-17.04.3-2/addons/rustcompletion/qrc_plugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.6.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/kate/kate-17.04.3-2.x86_64/src/kate-17.04.3/addons/rustcompletion/ui.rc
  0x0,0x0,0x2,0x1f,
  0x3c,
  0x3f,0x78,0x6d,0x6c,0x20,0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x3d,0x22,0x31,0x2e,
  0x30,0x22,0x20,0x65,0x6e,0x63,0x6f,0x64,0x69,0x6e,0x67,0x3d,0x22,0x55,0x54,0x46,
  0x2d,0x38,0x22,0x3f,0x3e,0xa,0x3c,0x21,0x44,0x4f,0x43,0x54,0x59,0x50,0x45,0x20,
  0x6b,0x70,0x61,0x72,0x74,0x67,0x75,0x69,0x3e,0xa,0x3c,0x67,0x75,0x69,0x20,0x6e,
  0x61,0x6d,0x65,0x3d,0x22,0x6b,0x74,0x65,0x72,0x75,0x73,0x74,0x63,0x6f,0x6d,0x70,
  0x6c,0x65,0x74,0x69,0x6f,0x6e,0x22,0x20,0x6c,0x69,0x62,0x72,0x61,0x72,0x79,0x3d,
  0x22,0x6b,0x74,0x65,0x72,0x75,0x73,0x74,0x63,0x6f,0x6d,0x70,0x6c,0x65,0x74,0x69,
  0x6f,0x6e,0x22,0x20,0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x3d,0x22,0x31,0x22,0x20,
  0x74,0x72,0x61,0x6e,0x73,0x6c,0x61,0x74,0x69,0x6f,0x6e,0x44,0x6f,0x6d,0x61,0x69,
  0x6e,0x3d,0x22,0x6b,0x74,0x65,0x72,0x75,0x73,0x74,0x63,0x6f,0x6d,0x70,0x6c,0x65,
  0x74,0x69,0x6f,0x6e,0x22,0x3e,0xa,0x20,0x20,0x3c,0x4d,0x65,0x6e,0x75,0x42,0x61,
  0x72,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x4d,0x65,0x6e,0x75,0x20,0x6e,0x61,0x6d,
  0x65,0x3d,0x22,0x65,0x64,0x69,0x74,0x22,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,
  0x3c,0x74,0x65,0x78,0x74,0x3e,0x26,0x61,0x6d,0x70,0x3b,0x45,0x64,0x69,0x74,0x3c,
  0x2f,0x74,0x65,0x78,0x74,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x53,0x65,
  0x70,0x61,0x72,0x61,0x74,0x6f,0x72,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,
  0x3c,0x41,0x63,0x74,0x69,0x6f,0x6e,0x20,0x6e,0x61,0x6d,0x65,0x3d,0x22,0x72,0x75,
  0x73,0x74,0x5f,0x66,0x69,0x6e,0x64,0x5f,0x64,0x65,0x66,0x69,0x6e,0x69,0x74,0x69,
  0x6f,0x6e,0x22,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x53,0x65,0x70,
  0x61,0x72,0x61,0x74,0x6f,0x72,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x2f,0x4d,
  0x65,0x6e,0x75,0x3e,0xa,0x20,0x20,0x3c,0x2f,0x4d,0x65,0x6e,0x75,0x42,0x61,0x72,
  0x3e,0xa,0x20,0x20,0x3c,0x4d,0x65,0x6e,0x75,0x20,0x6e,0x61,0x6d,0x65,0x3d,0x22,
  0x6b,0x74,0x65,0x78,0x74,0x65,0x64,0x69,0x74,0x6f,0x72,0x5f,0x70,0x6f,0x70,0x75,
  0x70,0x22,0x20,0x6e,0x6f,0x4d,0x65,0x72,0x67,0x65,0x3d,0x22,0x31,0x22,0x3e,0xa,
  0x20,0x20,0x20,0x20,0x3c,0x53,0x65,0x70,0x61,0x72,0x61,0x74,0x6f,0x72,0x2f,0x3e,
  0xa,0x20,0x20,0x20,0x20,0x3c,0x41,0x63,0x74,0x69,0x6f,0x6e,0x20,0x6e,0x61,0x6d,
  0x65,0x3d,0x22,0x72,0x75,0x73,0x74,0x5f,0x66,0x69,0x6e,0x64,0x5f,0x64,0x65,0x66,
  0x69,0x6e,0x69,0x74,0x69,0x6f,0x6e,0x22,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,
  0x53,0x65,0x70,0x61,0x72,0x61,0x74,0x6f,0x72,0x2f,0x3e,0xa,0x20,0x20,0x3c,0x2f,
  0x4d,0x65,0x6e,0x75,0x3e,0xa,0x3c,0x2f,0x67,0x75,0x69,0x3e,0xa,0x3c,0x21,0x2d,
  0x2d,0x20,0x6b,0x61,0x74,0x65,0x3a,0x20,0x73,0x70,0x61,0x63,0x65,0x2d,0x69,0x6e,
  0x64,0x65,0x6e,0x74,0x20,0x6f,0x6e,0x3b,0x20,0x69,0x6e,0x64,0x65,0x6e,0x74,0x2d,
  0x77,0x69,0x64,0x74,0x68,0x20,0x34,0x3b,0x20,0x72,0x65,0x70,0x6c,0x61,0x63,0x65,
  0x2d,0x74,0x61,0x62,0x73,0x20,0x6f,0x6e,0x3b,0x20,0x2d,0x2d,0x3e,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kterustcompletion
  0x0,0x11,
  0xf,0xb3,0x52,0xbe,
  0x0,0x6b,
  0x0,0x74,0x0,0x65,0x0,0x72,0x0,0x75,0x0,0x73,0x0,0x74,0x0,0x63,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x6c,0x0,0x65,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,
  
    // ui.rc
  0x0,0x5,
  0x0,0x7b,0xc5,0x83,
  0x0,0x75,
  0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
  // :/kxmlgui5/kterustcompletion
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
  // :/kxmlgui5/kterustcompletion/ui.rc
  0x0,0x0,0x0,0x3e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_plugin)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_plugin)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_plugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_plugin)(); }
   } dummy;
}

==> kate-debuginfo-17.08.3-1.tar.xz: usr/src/debug/kate-17.08.3-1/addons/rustcompletion/qrc_plugin.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/kate/kate-17.08.3-1.i686/src/kate-17.08.3/addons/rustcompletion/ui.rc
  0x0,0x0,0x2,0x1f,
  0x3c,
  0x3f,0x78,0x6d,0x6c,0x20,0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x3d,0x22,0x31,0x2e,
  0x30,0x22,0x20,0x65,0x6e,0x63,0x6f,0x64,0x69,0x6e,0x67,0x3d,0x22,0x55,0x54,0x46,
  0x2d,0x38,0x22,0x3f,0x3e,0xa,0x3c,0x21,0x44,0x4f,0x43,0x54,0x59,0x50,0x45,0x20,
  0x6b,0x70,0x61,0x72,0x74,0x67,0x75,0x69,0x3e,0xa,0x3c,0x67,0x75,0x69,0x20,0x6e,
  0x61,0x6d,0x65,0x3d,0x22,0x6b,0x74,0x65,0x72,0x75,0x73,0x74,0x63,0x6f,0x6d,0x70,
  0x6c,0x65,0x74,0x69,0x6f,0x6e,0x22,0x20,0x6c,0x69,0x62,0x72,0x61,0x72,0x79,0x3d,
  0x22,0x6b,0x74,0x65,0x72,0x75,0x73,0x74,0x63,0x6f,0x6d,0x70,0x6c,0x65,0x74,0x69,
  0x6f,0x6e,0x22,0x20,0x76,0x65,0x72,0x73,0x69,0x6f,0x6e,0x3d,0x22,0x31,0x22,0x20,
  0x74,0x72,0x61,0x6e,0x73,0x6c,0x61,0x74,0x69,0x6f,0x6e,0x44,0x6f,0x6d,0x61,0x69,
  0x6e,0x3d,0x22,0x6b,0x74,0x65,0x72,0x75,0x73,0x74,0x63,0x6f,0x6d,0x70,0x6c,0x65,
  0x74,0x69,0x6f,0x6e,0x22,0x3e,0xa,0x20,0x20,0x3c,0x4d,0x65,0x6e,0x75,0x42,0x61,
  0x72,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x4d,0x65,0x6e,0x75,0x20,0x6e,0x61,0x6d,
  0x65,0x3d,0x22,0x65,0x64,0x69,0x74,0x22,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,
  0x3c,0x74,0x65,0x78,0x74,0x3e,0x26,0x61,0x6d,0x70,0x3b,0x45,0x64,0x69,0x74,0x3c,
  0x2f,0x74,0x65,0x78,0x74,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x53,0x65,
  0x70,0x61,0x72,0x61,0x74,0x6f,0x72,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,
  0x3c,0x41,0x63,0x74,0x69,0x6f,0x6e,0x20,0x6e,0x61,0x6d,0x65,0x3d,0x22,0x72,0x75,
  0x73,0x74,0x5f,0x66,0x69,0x6e,0x64,0x5f,0x64,0x65,0x66,0x69,0x6e,0x69,0x74,0x69,
  0x6f,0x6e,0x22,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x20,0x20,0x3c,0x53,0x65,0x70,
  0x61,0x72,0x61,0x74,0x6f,0x72,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,0x2f,0x4d,
  0x65,0x6e,0x75,0x3e,0xa,0x20,0x20,0x3c,0x2f,0x4d,0x65,0x6e,0x75,0x42,0x61,0x72,
  0x3e,0xa,0x20,0x20,0x3c,0x4d,0x65,0x6e,0x75,0x20,0x6e,0x61,0x6d,0x65,0x3d,0x22,
  0x6b,0x74,0x65,0x78,0x74,0x65,0x64,0x69,0x74,0x6f,0x72,0x5f,0x70,0x6f,0x70,0x75,
  0x70,0x22,0x20,0x6e,0x6f,0x4d,0x65,0x72,0x67,0x65,0x3d,0x22,0x31,0x22,0x3e,0xa,
  0x20,0x20,0x20,0x20,0x3c,0x53,0x65,0x70,0x61,0x72,0x61,0x74,0x6f,0x72,0x2f,0x3e,
  0xa,0x20,0x20,0x20,0x20,0x3c,0x41,0x63,0x74,0x69,0x6f,0x6e,0x20,0x6e,0x61,0x6d,
  0x65,0x3d,0x22,0x72,0x75,0x73,0x74,0x5f,0x66,0x69,0x6e,0x64,0x5f,0x64,0x65,0x66,
  0x69,0x6e,0x69,0x74,0x69,0x6f,0x6e,0x22,0x2f,0x3e,0xa,0x20,0x20,0x20,0x20,0x3c,
  0x53,0x65,0x70,0x61,0x72,0x61,0x74,0x6f,0x72,0x2f,0x3e,0xa,0x20,0x20,0x3c,0x2f,
  0x4d,0x65,0x6e,0x75,0x3e,0xa,0x3c,0x2f,0x67,0x75,0x69,0x3e,0xa,0x3c,0x21,0x2d,
  0x2d,0x20,0x6b,0x61,0x74,0x65,0x3a,0x20,0x73,0x70,0x61,0x63,0x65,0x2d,0x69,0x6e,
  0x64,0x65,0x6e,0x74,0x20,0x6f,0x6e,0x3b,0x20,0x69,0x6e,0x64,0x65,0x6e,0x74,0x2d,
  0x77,0x69,0x64,0x74,0x68,0x20,0x34,0x3b,0x20,0x72,0x65,0x70,0x6c,0x61,0x63,0x65,
  0x2d,0x74,0x61,0x62,0x73,0x20,0x6f,0x6e,0x3b,0x20,0x2d,0x2d,0x3e,0xa,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kterustcompletion
  0x0,0x11,
  0xf,0xb3,0x52,0xbe,
  0x0,0x6b,
  0x0,0x74,0x0,0x65,0x0,0x72,0x0,0x75,0x0,0x73,0x0,0x74,0x0,0x63,0x0,0x6f,0x0,0x6d,0x0,0x70,0x0,0x6c,0x0,0x65,0x0,0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,
  
    // ui.rc
  0x0,0x5,
  0x0,0x7b,0xc5,0x83,
  0x0,0x75,
  0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5/kterustcompletion
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/kxmlgui5/kterustcompletion/ui.rc
  0x0,0x0,0x0,0x3e,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x89,0xa1,0xb8,0x70,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_plugin)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_plugin)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_plugin)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_plugin)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_plugin)(); }
   } dummy;
}
